@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: config.c,v 1.45 2005/03/16 20:13:10 hany Exp $
+ * $Id: config.c,v 1.46 2005/09/25 16:23:43 hany Exp $
  */
 
 #include <config.h>
@@ -15,6 +15,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -51,6 +52,7 @@ int   rpm2html_dump_rdf		= 0;
 int   rpm2html_dump_rdf_resources= 0;
 char *rpm2html_rdf_dir		= NULL;
 char *rpm2html_rdf_resources_dir= NULL;
+int   rpm2html_rdf_count_limit  = DEFAULT_RDF_COUNT_LIMIT;
 
 int  rpm2html_files = 0;
 int  rpm2html_size = 0;
@@ -252,6 +254,7 @@ rpmDirPtr rpmDirSearch(char *dirname) {
  */
 void addConfigEntry(char *rpmdir, char *name, char *value) {
     rpmDirPtr cur;
+    char *temp;
 
     if (rpm2htmlVerbose > 1)
 	printf("addConfigEntry(\"%s\", \"%s\", \"%s\")\n", rpmdir, name, value);
@@ -315,6 +318,13 @@ void addConfigEntry(char *rpmdir, char *name, char *value) {
 	    }
 	} else if (!strcasecmp(name, "rdf_resources_dir")) {
 	    rpm2html_rdf_resources_dir = xmlStrdup(value);
+	} else if (!strcasecmp(name, "rdf_count_limit")) {
+	    rpm2html_rdf_count_limit = strtol(value, &temp, 10);
+	    if ((*value == '\0') || (*temp != '\0')) {
+		printf("Config file : %s global entry ignored,\n", name);
+		printf("\tuse \"rdf_count_limit=<number>\"\n");
+		rpm2html_rdf_count_limit = DEFAULT_RDF_COUNT_LIMIT;
+	    }
 	} else if (!strcasecmp(name, "html")) {
 	    if ((!strcasecmp(value, "true")) ||
 	        (!strcasecmp(value, "yes"))) {
