@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpmdata.c,v 1.51 2000/12/10 17:10:38 veillard Exp $
+ * $Id: rpmdata.c,v 1.53 2005/03/16 20:17:12 hany Exp $
  */
 
 #include <config.h>
@@ -897,6 +897,62 @@ char *extractURL(char *string) {
     return(buf);
 }
 
+/*
+ * Try to protect an e-mail address from a spam bot.
+ * The "<someone@domain.tld>" is replaced
+ *      with "<someone(at)domain.tld>".
+ */
+
+static unsigned char *buffer = NULL;
+static int buffer_size = 2000;
+static char *at = "(at)";
+char *protectEmail(char *string) {
+    if (rpm2html_protect_emails == 0 || string == NULL)
+        return string;
+
+    unsigned char *cur, *end;
+    unsigned char c;
+    int magick = 0;
+
+    if (buffer == NULL) {
+        buffer = (char *) xmlMalloc(buffer_size * sizeof(char));
+	if (buffer == NULL) {
+	    perror("xmlMalloc failed");
+	    exit(1);
+	}
+    }
+    cur = &buffer[0];
+    end = &buffer[buffer_size - 20];
+
+    while (*string != '\0') {
+        if (cur >= end) {
+	    int delta = cur - buffer;
+
+	    buffer_size *= 2;
+	    buffer = (char *) xmlRealloc(buffer, buffer_size * sizeof(char));
+	    if (buffer == NULL) {
+		perror("xmlMalloc failed");
+		exit(1);
+	    }
+	    end = &buffer[buffer_size - 20];
+	    cur = &buffer[delta];
+	}
+        c = (unsigned char) *(string++);
+        if (c == '<')
+            magick = 1;
+        if (c == '>')
+            magick = 0;
+	if (c == '@' && magick) {
+	    strcpy(cur, at);
+	    cur += strlen(at);
+	} else {
+	    *(cur++) = c;
+	}
+    }
+    *cur = '\0';
+    return(buffer);
+}
+
 /*
  * Create a root directory for the installation space, i.e. the
  * filesystem that would be created if the packages were installed
