@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpmopen.c,v 1.114 2005/04/29 20:58:33 hany Exp $
+ * $Id: rpmopen.c,v 1.115 2005/09/25 15:21:58 hany Exp $
  */
 
 #include <config.h>
@@ -160,8 +160,8 @@ checkResourceName(const char *res)
             res++;
         else
             return (0);
-        if ((res - base) > 100)
-            return (0);
+        //if ((res - base) > 100)
+        //    return (0);
     }
     return (1);
 }
@@ -209,8 +209,8 @@ checkGroupName(const char *res)
             res++;
         else
             return (0);
-        if ((res - base) > 60)
-            return (0);
+        //if ((res - base) > 60)
+        //    return (0);
     }
     return (1);
 }
@@ -235,8 +235,8 @@ checkVersionName(const char *res)
             res++;
         else
             return (0);
-        if ((res - base) > 20)
-            return (0);
+        //if ((res - base) > 20)
+        //    return (0);
     }
     return (1);
 }
